@@ -255,17 +255,37 @@ setMethodS3("getWritablePathname", "Arguments", function(static, ..., mustExist=
     }
   } else {
     # Check if parent directory exists
-    parent <- getParent(pathname);
-    if (!isDirectory(parent)) {
+    path <- getParent(pathname);
+    if (!isDirectory(path)) {
       # Check if parent directory should be created
       if (!mkdirs) {
-        parent <- Arguments$getReadablePath(parent, mustExist=TRUE);
+        path <- Arguments$getReadablePath(path, mustExist=TRUE);
       }
 
-      if (!mkdirs(parent)) {
-  	throw("Failed not create file path: ", parent);
+      if (!mkdirs(path)) {
+  	throw("Failed not create file path: ", path);
       }
     }
+
+    # Check if file permissions allow to create a file in the directory
+    pathT <- ifelse(is.null(path), ".", path);
+    if (fileAccess(pathT, mode=2) == -1) {
+      throw("No write permission for directory: ", path);
+    }
+
+    # Try to create a file
+    filenameT <- basename(tempfile());
+    pathnameT <- filePath(path, filenameT);
+    on.exit({
+      if (isFile(pathnameT)) {
+        file.remove(pathnameT);
+      }
+    }, add=TRUE);
+    tryCatch({
+      cat(file=pathnameT, Sys.time());
+    }, error = function(ex) {
+      throw("No permission to create a new file in directory: ", path);
+    });
   }
 
   pathname;
@@ -273,6 +293,12 @@ setMethodS3("getWritablePathname", "Arguments", function(static, ..., mustExist=
 
 
 
+setMethodS3("getWritablePath", "Arguments", function(static, path=NULL, ...) {
+  pathname <- getWritablePathname(static, file="dummy-not-created", path=path, ...);
+  getParent(pathname);
+}, static=TRUE, protected=TRUE)
+
+
 
 setMethodS3("getDirectory", "Arguments", function(static, path=NULL, ..., mustExist=FALSE, mkdirs=TRUE) {
   # Argument 'mustExist':
@@ -298,12 +324,6 @@ setMethodS3("getDirectory", "Arguments", function(static, path=NULL, ..., mustEx
 }, static=TRUE, protected=TRUE)
 
 
-setMethodS3("getWritablePath", "Arguments", function(static, path=NULL, ...) {
-  pathname <- getWritablePathname(static, file="dummy-not-created", path=path, ...);
-  getParent(pathname); 
-}, static=TRUE, protected=TRUE)
-
-
 
 #########################################################################/**
 # @RdocMethod getVector
@@ -937,6 +957,9 @@ setMethodS3("getReadablePath", "Arguments", function(static, path=NULL, ...) {
 
 ############################################################################
 # HISTORY:
+# 2009-10-30
+# o Now Arguments$getWritablePathname(path) validates that there is enough
+#   file permissions so that a file can be created in the 'path' directory.
 # 2009-06-29
 # o Added argument 'useNames=FALSE' to getCharacters() of Arguments.
 #   Don't remember why I didn't want names in the first place (see below).
